aboutsummaryrefslogtreecommitdiffstats
path: root/config/config.go
diff options
context:
space:
mode:
Diffstat (limited to 'config/config.go')
-rw-r--r--config/config.go8
1 files changed, 5 insertions, 3 deletions
diff --git a/config/config.go b/config/config.go
index dc76571..a2b5012 100644
--- a/config/config.go
+++ b/config/config.go
@@ -7,8 +7,10 @@ import (
)
const (
- // DefaultRefSpec is the default refspec used, when none is given
- DefaultRefSpec = "+refs/heads/*:refs/remotes/%s/*"
+ // DefaultFetchRefSpec is the default refspec used for fetch.
+ DefaultFetchRefSpec = "+refs/heads/*:refs/remotes/%s/*"
+ // DefaultPushRefSpec is the default refspec used for push.
+ DefaultPushRefSpec = "refs/heads/*:refs/heads/*"
)
// ConfigStorer generic storage of Config object
@@ -72,7 +74,7 @@ func (c *RemoteConfig) Validate() error {
}
if len(c.Fetch) == 0 {
- c.Fetch = []RefSpec{RefSpec(fmt.Sprintf(DefaultRefSpec, c.Name))}
+ c.Fetch = []RefSpec{RefSpec(fmt.Sprintf(DefaultFetchRefSpec, c.Name))}
}
return nil